guitool_ibeis
=============

|ReadTheDocs| |Pypi| |Downloads| |Codecov| |CircleCI| |Travis| |Appveyor| 

Helpers for pyqt4/pyqt5 gui development for the IBEIS project.

Depends on `vtool_ibeis` and `utool`.

Vision Tools - tools for computer vision. Part of the WildMe / IBEIS Project.


.. |CircleCI| image:: https://circleci.com/gh/Erotemic/guitool.svg?style=svg
    :target: https://circleci.com/gh/Erotemic/guitool
.. |Travis| image:: https://img.shields.io/travis/Erotemic/guitool/master.svg?label=Travis%20CI
   :target: https://travis-ci.org/Erotemic/guitool?branch=master
.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/github/Erotemic/guitool?branch=master&svg=True
   :target: https://ci.appveyor.com/project/Erotemic/guitool/branch/master
.. |Codecov| image:: https://codecov.io/github/Erotemic/guitool/badge.svg?branch=master&service=github
   :target: https://codecov.io/github/Erotemic/guitool?branch=master
.. |Pypi| image:: https://img.shields.io/pypi/v/guitool_ibeis.svg
   :target: https://pypi.python.org/pypi/guitool_ibeis
.. |Downloads| image:: https://img.shields.io/pypi/dm/guitool_ibeis.svg
   :target: https://pypistats.org/packages/guitool_ibeis
.. |ReadTheDocs| image:: https://readthedocs.org/projects/guitool_ibeis/badge/?version=latest
    :target: http://guitool_ibeis.readthedocs.io/en/latest/
